# Applications

Ragas in action. Examples of how to use Ragas in various applications and
usecases to solve problems you might encounter when your building.

```{toctree}
:caption: Applications

data_preparation
compare_embeddings
```
